@@ -3,7 +3,7 @@
 -- Module:      Blaze.Text.Int
 -- Copyright:   (c) 2011 MailRank, Inc.
 -- License:     BSD3
--- Maintainer:  Bryan O'Sullivan <bos@mailrank.com>
+-- Maintainer:  Bryan O'Sullivan <bos@serpentine.com>
 -- Stability:   experimental
 -- Portability: portable
 --
@@ -40,7 +40,7 @@ import GHC.Integer.GMP.Internals
 # define PAIR(a,b) (a,b)
 #endif
 
-integral :: Integral a => a -> Builder
+integral :: (Integral a, Show a) => a -> Builder
 {-# RULES "integral/Int" integral = bounded :: Int -> Builder #-}
 {-# RULES "integral/Int8" integral = bounded :: Int8 -> Builder #-}
 {-# RULES "integral/Int16" integral = bounded :: Int16 -> Builder #-}
